# Community

Connect with the pytest-ansible community!

Join the Ansible forum to ask questions, get help, and interact with the
community.

- [Get Help](https://forum.ansible.com/c/help/6): get help or help others.
  Please add appropriate tags if you start new discussions, for example you can
  use the `devtools` tag.
- [Social Spaces](https://forum.ansible.com/c/chat/4): meet and interact with
  fellow enthusiasts.
- [News & Announcements](https://forum.ansible.com/c/news/5): track project-wide
  announcements including social events.

To get release announcements and important changes from the community, see the
[Bullhorn newsletter](https://docs.ansible.com/ansible/devel/community/communication.html#the-bullhorn).

If you encounter security-related concerns, report them via email to
[security@ansible.com](mailto:security@ansible.com).
